Bot class
Model represents a bot.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Bot's Id.
final
- information → BotInfo
-
Information about the bot.
final
- links → List
-
Bot's links;
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- server → BotServer?
-
Server, that attached to the bot.
final
- shortCode → String?
-
Bot's page short code.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited