BotInfo class
This model represents Information about the bot.
Constructors
-
BotInfo({required int bumps, required int added, required int permissions, String? prefix, List<
String?> ? tags, List<String?> ? developers, Links? links, String? library, String? shortDescription, String? longDescription, String? badge, BotStats? stats, String? status}) -
BotInfo.parseJson(Map<
String, dynamic> json)
Properties
- added → int
-
How many times users have added the bot?
final
- badge → String?
-
Bot's badge.
final
- bumps → int
-
Bumps Count,
final
-
developers
→ List<
String?> ? -
Bot's developers list.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- library → String?
-
Library bot is based on.
final
- links → Links?
-
Bot's social medias.
final
- longDescription → String?
-
Bot's long description.
final
- permissions → int
-
Bot's (required) permissions.
final
- prefix → String?
-
Bot's prefix.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortDescription → String?
-
Bot's short description.
final
- stats → BotStats?
-
Bot's stats.
final
- status → String?
-
Bot's approval status.
final
-
Bot's search-tags.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited